==> gnuradio-core-2.5.tar.gz: gnuradio-core-2.5/src/lib/swig/gnuradio_swig_bug_workaround.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H
#define INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H

/*
 * This include files works around a bug in SWIG 1.3.21 and 22
 * where it fails to emit these declarations when doing
 * %import "gnuradio.i"
 */

class gr_add_cc;
class gr_add_const_cc;
class gr_add_const_ff;
class gr_add_const_ii;
class gr_add_const_sf;
class gr_add_const_ss;
class gr_add_ff;
class gr_add_ii;
class gr_add_ss;
class gr_base_error_handler;
class gr_block;
class gr_bytes_to_syms;
class gr_check_counting_s;
class gr_check_lfsr_32k_s;
class gr_complex_to_arg;
class gr_complex_to_float;
class gr_complex_to_imag;
class gr_complex_to_mag;
class gr_complex_to_real;
class gr_deinterleave;
class gr_divide_cc;
class gr_divide_ff;
class gr_divide_ii;
class gr_divide_ss;
class gr_error_handler;
class gr_fft_vcc;
class gr_fft_vfc;
class gr_file_descriptor_sink;
class gr_file_descriptor_source;
class gr_file_error_handler;
class gr_file_sink;
class gr_file_source;
class gr_filter_delay_fc;
class gr_fir_filter_ccc;
class gr_fir_filter_ccf;
class gr_fir_filter_fcc;
class gr_fir_filter_fff;
class gr_fir_filter_fsf;
class gr_fir_filter_scc;
class gr_float_to_complex;
class gr_float_to_short;
class gr_freq_xlating_fir_filter_ccc;
class gr_freq_xlating_fir_filter_ccf;
class gr_freq_xlating_fir_filter_fcc;
class gr_freq_xlating_fir_filter_fcf;
class gr_freq_xlating_fir_filter_scc;
class gr_freq_xlating_fir_filter_scf;
class gr_frequency_modulator_fc;
class gr_head;
class gr_hilbert_fc;
class gr_iir_filter_ffd;
class gr_interleave;
class gr_interleaved_short_to_complex;
class gr_interp_fir_filter_ccc;
class gr_interp_fir_filter_ccf;
class gr_interp_fir_filter_fcc;
class gr_interp_fir_filter_fff;
class gr_interp_fir_filter_fsf;
class gr_interp_fir_filter_scc;
class gr_keep_one_in_n;
class gr_lfsr_32k_source_s;
class gr_msg_handler;
class gr_msg_queue;
class gr_multiply_cc;
class gr_multiply_const_cc;
class gr_multiply_const_ff;
class gr_multiply_const_ii;
class gr_multiply_const_ss;
class gr_multiply_ff;
class gr_multiply_ii;
class gr_multiply_ss;
class gr_mute_cc;
class gr_mute_ff;
class gr_mute_ii;
class gr_mute_ss;
class gr_nlog10_ff;
class gr_noise_source_c;
class gr_noise_source_f;
class gr_noise_source_i;
class gr_noise_source_s;
class gr_nop;
class gr_null_sink;
class gr_null_source;
class gr_oscope_sink_f;
class gr_oscope_sink_x;
class gr_parallel_to_serial;
class gr_quadrature_demod_cf;
class gr_rms_cf;
class gr_rms_ff;
class gr_serial_to_parallel;
class gr_short_to_float;
class gr_sig_source_c;
class gr_sig_source_f;
class gr_sig_source_i;
class gr_sig_source_s;
class gr_simple_correlator;
class gr_simple_framer;
class gr_simple_squelch_cc;
class gr_single_pole_iir_filter_ff;
class gr_sub_cc;
class gr_sub_ff;
class gr_sub_ii;
class gr_sub_ss;
class gr_sync_block;
class gr_sync_decimator;
class gr_sync_interpolator;
class gr_vector_sink_b;
class gr_vector_sink_c;
class gr_vector_sink_f;
class gr_vector_sink_i;
class gr_vector_sink_s;
class gr_vector_source_b;
class gr_vector_source_c;
class gr_vector_source_f;
class gr_vector_source_i;
class gr_vector_source_s;
class microtune_4702_eval_board;
class microtune_4937_eval_board;
class microtune_xxxx_eval_board;

#endif /* INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H */

==> gnuradio-core_2.6.orig.tar.gz: gnuradio-core-2.6.orig/src/lib/swig/gnuradio_swig_bug_workaround.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H
#define INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H

/*
 * This include files works around a bug in SWIG 1.3.21 and 22
 * where it fails to emit these declarations when doing
 * %import "gnuradio.i"
 */

class gr_add_cc;
class gr_add_const_cc;
class gr_add_const_ff;
class gr_add_const_ii;
class gr_add_const_sf;
class gr_add_const_ss;
class gr_add_ff;
class gr_add_ii;
class gr_add_ss;
class gr_base_error_handler;
class gr_block;
class gr_bytes_to_syms;
class gr_check_counting_s;
class gr_check_lfsr_32k_s;
class gr_clock_recovery_mm_ff;
class gr_complex_to_arg;
class gr_complex_to_float;
class gr_complex_to_imag;
class gr_complex_to_mag;
class gr_complex_to_real;
class gr_conjugate_cc;
class gr_deinterleave;
class gr_divide_cc;
class gr_divide_ff;
class gr_divide_ii;
class gr_divide_ss;
class gr_error_handler;
class gr_fake_channel_decoder_pp;
class gr_fake_channel_encoder_pp;
class gr_fft_filter_ccc;
class gr_fft_filter_fff;
class gr_fft_vcc;
class gr_fft_vfc;
class gr_file_descriptor_sink;
class gr_file_descriptor_source;
class gr_file_error_handler;
class gr_file_sink;
class gr_file_source;
class gr_filter_delay_fc;
class gr_fir_filter_ccc;
class gr_fir_filter_ccf;
class gr_fir_filter_fcc;
class gr_fir_filter_fff;
class gr_fir_filter_fsf;
class gr_fir_filter_scc;
class gr_float_to_char;
class gr_float_to_complex;
class gr_float_to_short;
class gr_float_to_uchar;
class gr_freq_xlating_fir_filter_ccc;
class gr_freq_xlating_fir_filter_ccf;
class gr_freq_xlating_fir_filter_fcc;
class gr_freq_xlating_fir_filter_fcf;
class gr_freq_xlating_fir_filter_scc;
class gr_freq_xlating_fir_filter_scf;
class gr_frequency_modulator_fc;
class gr_head;
class gr_hilbert_fc;
class gr_iir_filter_ffd;
class gr_interleave;
class gr_interleaved_short_to_complex;
class gr_interp_fir_filter_ccc;
class gr_interp_fir_filter_ccf;
class gr_interp_fir_filter_fcc;
class gr_interp_fir_filter_fff;
class gr_interp_fir_filter_fsf;
class gr_interp_fir_filter_scc;
class gr_keep_one_in_n;
class gr_lfsr_32k_source_s;
class gr_lms_dfe_ff;
class gr_message_sink;
class gr_message_source;
class gr_msg_handler;
class gr_msg_queue;
class gr_multiply_cc;
class gr_multiply_const_cc;
class gr_multiply_const_ff;
class gr_multiply_const_ii;
class gr_multiply_const_ss;
class gr_multiply_ff;
class gr_multiply_ii;
class gr_multiply_ss;
class gr_mute_cc;
class gr_mute_ff;
class gr_mute_ii;
class gr_mute_ss;
class gr_nlog10_ff;
class gr_noise_source_c;
class gr_noise_source_f;
class gr_noise_source_i;
class gr_noise_source_s;
class gr_nop;
class gr_null_sink;
class gr_null_source;
class gr_oscope_sink_f;
class gr_oscope_sink_x;
class gr_packet_sink;
class gr_parallel_to_serial;
class gr_pll_carriertracking_cc;
class gr_pll_freqdet_cf;
class gr_pll_refout_cc;
class gr_probe_avg_mag_sqrd_c;
class gr_probe_avg_mag_sqrd_f;
class gr_probe_signal_f;
class gr_quadrature_demod_cf;
class gr_rational_resampler_base_ccc;
class gr_rational_resampler_base_ccf;
class gr_rational_resampler_base_fcc;
class gr_rational_resampler_base_fff;
class gr_rational_resampler_base_fsf;
class gr_rational_resampler_base_scc;
class gr_rms_cf;
class gr_rms_ff;
class gr_serial_to_parallel;
class gr_short_to_float;
class gr_sig_source_c;
class gr_sig_source_f;
class gr_sig_source_i;
class gr_sig_source_s;
class gr_simple_correlator;
class gr_simple_framer;
class gr_simple_squelch_cc;
class gr_single_pole_iir_filter_ff;
class gr_stream_to_streams;
class gr_streams_to_stream;
class gr_streams_to_vector;
class gr_sub_cc;
class gr_sub_ff;
class gr_sub_ii;
class gr_sub_ss;
class gr_sync_block;
class gr_sync_decimator;
class gr_sync_interpolator;
class gr_threshold_ff;
class gr_throttle;
class gr_vco_f;
class gr_vector_sink_b;
class gr_vector_sink_c;
class gr_vector_sink_f;
class gr_vector_sink_i;
class gr_vector_sink_s;
class gr_vector_source_b;
class gr_vector_source_c;
class gr_vector_source_f;
class gr_vector_source_i;
class gr_vector_source_s;
class gr_vector_to_streams;
class microtune_4702_eval_board;
class microtune_4937_eval_board;
class microtune_xxxx_eval_board;

#endif /* INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H */
